/*
 * mainwindow.cpp - part of DialWidget
 * Copyright © 2007 Michael Pyne <michael.pyne@kdemail.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include "mainwindow.h"

#include <QtDebug>
#include <QGridLayout>
#include <QLabel>

#include "verticallabel.h"
#include "S5WDial.h"
#include "sensor.h"

class MainWindow::Private
{
    public:
        QLabel *label;
};

MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent),
    d(new MainWindow::Private)
{
    QWidget *w = new QWidget(this);
    setCentralWidget(w);

    QHBoxLayout *hBox = new QHBoxLayout(w);
    QVBoxLayout *vBox = new QVBoxLayout;
    QGridLayout *gl = new QGridLayout;

    hBox->addLayout(vBox);
    hBox->addLayout(gl, 1);

    QWidget *label = new VerticalLabel("CPU 0", this);
    vBox->addWidget(label);

    label = new VerticalLabel("CPU 1", this);
    vBox->addWidget(label);

#ifdef Q_WS_X11
    S5WDial *dial = new S5WDial(w);
    gl->addWidget(dial, 0, 0);

    Sensor *sensor = new CPULoadSensor(this, 0);
    sensor->setBuddy(dial);

    dial = new S5WDial(w);
    gl->addWidget(dial, 1, 0);

    sensor = new CPULoadSensor(this, 1);
    sensor->setBuddy(dial);

    sensor = new CPUFreqSensor(this, 0);
    dial = new S5WDial(w);
    sensor->setBuddy(dial);
    gl->addWidget(dial, 0, 2);

    sensor = new CPUFreqSensor(this, 1);
    dial = new S5WDial(w);
    sensor->setBuddy(dial);
    gl->addWidget(dial, 1, 2);

    // Add spacing column
    gl->setColumnMinimumWidth(3, 15);

    dial = new S5WDial(w);
    S5WDial *dial2 = new S5WDial(w);
    gl->addWidget(dial, 1, 4);
    gl->addWidget(dial2, 0, 4);

    sensor = new FanSpeedSensor(this);

    // Setup dial 1 manually
    dial->setValue(2200);
    dial->setMinimum(2200);
    dial->setMaximum(2550);
    dial->setTripPoint(2500);
    dial->setTickInterval(50);
    dial->setLabel("RPM");
    connect(sensor, SIGNAL(valueChanged(double)), dial, SLOT(setValue(double)));

    sensor->setBuddy(dial2);

    dial = new S5WDial(w);
    sensor = new CPUTempSensor(this, 0);

    sensor->setBuddy(dial);
    gl->addWidget(dial, 0, 1);

    dial = new S5WDial(w);
    sensor = new CPUTempSensor(this, 1);

    sensor->setBuddy(dial);
    gl->addWidget(dial, 1, 1);

    // Add spacing column
    gl->setColumnMinimumWidth(4, 15);

    dial = new S5WDial(w);
    sensor = new NetSpeedSensor(this, NetSpeedSensor::RxSpeed);
    sensor->setRange(25.0, 275.0);
    sensor->setInterval(25.0);
    sensor->setBuddy(dial);
    gl->addWidget(dial, 0, 5);

    dial = new S5WDial(w);
    sensor = new NetSpeedSensor(this, NetSpeedSensor::TxSpeed);
    sensor->setBuddy(dial);
    gl->addWidget(dial, 1, 5);

#elif defined(Q_WS_WIN)

    S5WDial *dial = new S5WDial(w);
    dial->setAnimationEnabled(false);
    gl->addWidget(dial, 0, 0);

    Sensor *sensor = new CPULoadSensor(this);
    sensor->setBuddy(dial);

    d->label = new QLabel("Load:", this);
    gl->addWidget(d->label, 1, 0);

    connect(sensor, SIGNAL(valueChanged(double)), SLOT(valueChanged(double)));
#endif
}

void MainWindow::valueChanged(double value)
{
    d->label->setText(QString("Load: %1").arg(value));
}

// vim: set fileencoding=utf-8 encoding=utf-8:
