#ifndef DIAL_DEMO_SENSOR_H
#define DIAL_DEMO_SENSOR_H

#include <QObject>
#include <QString>
#include <QTime>

class Sensor : public QObject
{
    Q_OBJECT

public:
    void setBuddy(QObject *buddy);

    // These functions should generally be called with appropriate defaults by
    // subclass ctors.  They are public so that they can be overridden if
    // necessary (for example, having both a wide range and narrow range device.
    void setTripPoint(double tripPoint);
    void setInterval(double interval);
    void setLabel(const QString &label);
    void setRange(double min, double max);

    double value() const;

signals:
    void valueChanged(double value);

protected:
    Sensor(QObject *parent, int timeout);

    void setValue(double value);

    int readI2CValue(const QString &fileName, bool *ok);
    int readValueFromFile(const QString &fileName, bool *ok);

private slots:
    virtual void updateValue() = 0;

private:
    double m_tripPoint;
    double m_min, m_max;
    double m_interval;
    double m_value;
    QString m_label, m_fileName; // m_fileName used to cache sensor file.
    QObject *m_buddy;
};

#ifdef Q_WS_X11 // Linux
class FanSpeedSensor : public Sensor
{
    Q_OBJECT

public:
    FanSpeedSensor(QObject *parent);

private slots:
    virtual void updateValue();
};

class UPCSensor : public Sensor
{
    Q_OBJECT

public:
    UPCSensor(QObject *parent, const QString &parameter);

private slots:
    virtual void updateValue();

private:
    QString m_parameter;
};

class CPUFreqSensor : public Sensor
{
    Q_OBJECT

public:
    CPUFreqSensor(QObject *parent, int cpuid = 0);

private slots:
    virtual void updateValue();

private:
    int m_cpuid;
};

class CPUTempSensor : public Sensor
{
    Q_OBJECT

public:
    CPUTempSensor(QObject *parent, int CPUID = 0);

private slots:
    virtual void updateValue();

private:
    int m_cpuId;
};

class NetSpeedSensor : public Sensor
{
    Q_OBJECT

public:
    enum NetSpeedType { RxSpeed, TxSpeed };

    NetSpeedSensor(QObject *parent, NetSpeedType speed);

private slots:
    virtual void updateValue();

private:
    quint64 currentRxBytes();

    quint64 m_bytesRx;
    NetSpeedType m_speed;
    QTime m_timeElapsed;
};

struct CPULoadInfo
{
    quint64 userTicks, sysTicks, niceTicks, idleTicks;
};

class CPULoadSensor : public Sensor
{
    Q_OBJECT

public:
    CPULoadSensor(QObject *parent, int cpuId = -1);

private slots:
    virtual void updateValue();

private:
    bool readCPULoad(CPULoadInfo &load);

    CPULoadInfo m_lastLoad;
    int m_cpuId;
};
#endif

// Windows-only sensors
#ifdef Q_WS_WIN
class CPULoadSensor : public Sensor
{
    Q_OBJECT

public:
    CPULoadSensor(QObject *parent);
    ~CPULoadSensor();

private slots:
    virtual void updateValue();
};
#endif

#endif
