#include "verticallabel.h"

#include <QSize>
#include <QWidget>
#include <QPainter>
#include <QFontMetrics>

VerticalLabel::VerticalLabel(const QString &text, QWidget *parent)
  : QWidget(parent), m_text(text)
{
    setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
}

void VerticalLabel::setText(const QString &newText)
{
    m_text = newText;
    update();
}

QString VerticalLabel::text() const
{
    return m_text;
}

QSize VerticalLabel::sizeHint() const
{
    QFontMetrics fm = fontMetrics();

    QSize s = fontMetrics().boundingRect(m_text).size();
    s.transpose();
    return s;
}

void VerticalLabel::paintEvent(QPaintEvent *)
{
    QPainter p(this);

    p.translate(0, height());
    p.rotate(-90.0);
    p.setBrush(Qt::NoBrush);

    QRect r = QRect(0, 0, height(), width());
    p.drawText(r, Qt::AlignCenter, m_text);
}
